@@ -1,5 +1,5 @@
 from dataclasses import dataclass
-from typing import Dict, List, Union
+from typing import Dict, List, Optional, Union
 
 
 class ScoreException(Exception):
@@ -9,13 +9,13 @@ class ScoreException(Exception):
 SeriesDict = Dict[str, float]
 DataFrameDict = Dict[str, SeriesDict]
 RocDict = Dict[str, List[float]]
-ScoreDict = Dict[str, Union[float, SeriesDict, DataFrameDict, Dict[str, RocDict]]]
+ScoreDict = Dict[str, Union[float, Optional[float], SeriesDict, DataFrameDict, Dict[str, RocDict]]]
 
 
 @dataclass
 class Score:
     overall: float
-    validation: float
+    validation: Optional[float]
 
     def to_string(self) -> str:
         output = f'Overall: {self.overall}\n'
